;;; -*-lisp-*-
;;;
;;; $Id$
;;;
;;; Basic system-specific stuff
;;;
;;; (c) 2005 Mark Wooding
;;;

;;;----- Licensing notice ---------------------------------------------------
;;;
;;; This program is free software; you can redistribute it and/or modify
;;; it under the terms of the GNU General Public License as published by
;;; the Free Software Foundation; either version 2 of the License, or
;;; (at your option) any later version.
;;; 
;;; This program is distributed in the hope that it will be useful,
;;; but WITHOUT ANY WARRANTY; without even the implied warranty of
;;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
;;; GNU General Public License for more details.
;;; 
;;; You should have received a copy of the GNU General Public License
;;; along with this program; if not, write to the Free Software Foundation,
;;; Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.

(defpackage #:mdw.runlisp
  (:use #:common-lisp #+cmu #:extensions)
  (:export #:*lisp-interpreter* #:*command-line-strings*))
(defpackage #:mdw.sys-base
  (:use #:common-lisp #+cmu #:extensions #:mdw.runlisp)
  (:export #:exit #:hard-exit #:*program-name* #:*command-line-strings*))
(in-package #:mdw.sys-base)

;;; --- This is currently all a bit CMUCL-specific ---

#+cmu
(defun exit (&optional (code 0))
  "Polite way to end a program.  If running in an interactive Lisp, just
   return to the top-level REPL."
  (if *batch-mode*
      (throw 'lisp::%end-of-the-world code)
      (progn
        (unless (zerop code)
          (format t "~&Exiting unsuccessfully with code ~D.~%" code))
        (abort))))

#+cmu
(defun hard-exit (&optional (code 0))
  "Stops the program immediately in its tracks.  Does nothing else.  Use
   after fork, for example, to avoid flushing buffers."
  (declare (type (unsigned-byte 32) code))
  (unix::void-syscall ("_exit" c-call:int) code))

#+cmu
(defvar *program-name* (pathname-name (car *command-line-strings*))
  "A plausible guess at the program's name, stripped of strange extensions.")

;;;----- That's all, folks --------------------------------------------------
